@@ -19,7 +19,7 @@ sub mvp_multivalue_args { qw(
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2024-01-08'; # DATE
 our $DIST = 'Pod-Weaver-Plugin-Sah-Schemas'; # DIST
-our $VERSION = '0.076'; # VERSION
+our $VERSION = '0.077'; # VERSION
 
 sub weave_section {
     no strict 'refs'; ## no critic: TestingAndDebugging::ProhibitNoStrict
@@ -172,7 +172,7 @@ sub weave_section {
                     push @pod, "Used completion: ";
                     for my $i (0 .. $#{$xcompletions}) {
                         my $cname = ref $xcompletions->[$i] ? $xcompletions->[$i][0] : $xcompletions->[$i];
-                        push @pod, ", " if $i; push @pod, "L<$cname|Perinci::Sub::XComplete::$cname>" }
+                        push @pod, ", " if $i; push @pod, "L<$cname|Perinci::Sub::XCompletion::$cname>" }
                     push @pod, "\n\n";
                 }
 
@@ -446,7 +446,7 @@ Pod::Weaver::Plugin::Sah::Schemas - Plugin to use when building Sah::Schemas::*
 
 =head1 VERSION
 
-This document describes version 0.076 of Pod::Weaver::Plugin::Sah::Schemas (from Perl distribution Pod-Weaver-Plugin-Sah-Schemas), released on 2024-01-08.
+This document describes version 0.077 of Pod::Weaver::Plugin::Sah::Schemas (from Perl distribution Pod-Weaver-Plugin-Sah-Schemas), released on 2024-01-08.
 
 =head1 SYNOPSIS
 
